@@ -39,8 +39,11 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         if(gpu->coreCount != FF_GPU_CORE_COUNT_UNSET)
             ffStrbufAppendF(&output, " (%d)", gpu->coreCount);
 
-        if(gpu->frequency == gpu->frequency && gpu->frequency > 0 /* Inactive? */)
-            ffStrbufAppendF(&output, " @ %.2f GHz", gpu->frequency);
+        if(gpu->frequency > 0)
+        {
+            ffStrbufAppendS(&output, " @ ");
+            ffParseFrequency(gpu->frequency, &output);
+        }
 
         if(gpu->temperature == gpu->temperature) //FF_GPU_TEMP_UNSET
         {
@@ -84,6 +87,9 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         if (gpu->shared.total != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->shared.total, &sTotal);
         if (gpu->shared.used != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->shared.used, &sUsed);
 
+        FF_STRBUF_AUTO_DESTROY frequency = ffStrbufCreate();
+        ffParseFrequency(gpu->frequency, &frequency);
+
         FF_PRINT_FORMAT_CHECKED(FF_GPU_MODULE_NAME, index, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_GPU_NUM_FORMAT_ARGS, ((FFformatarg[]) {
             {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->vendor, "vendor"},
             {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->name, "name"},
@@ -96,7 +102,7 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
             {FF_FORMAT_ARG_TYPE_STRBUF, &sTotal, "shared-total"},
             {FF_FORMAT_ARG_TYPE_STRBUF, &sUsed, "shared-used"},
             {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->platformApi, "platform-api"},
-            {FF_FORMAT_ARG_TYPE_DOUBLE, &gpu->frequency, "frequency"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &frequency, "frequency"},
         }));
     }
 }
@@ -177,6 +183,7 @@ bool ffParseGPUCommandOptions(FFGPUOptions* options, const char* key, const char
             { "discrete", FF_GPU_TYPE_DISCRETE },
             {},
         });
+        return true;
     }
 
     if (ffPercentParseCommandOptions(key, subKey, value, &options->percent))
